@@ -38,7 +38,7 @@ __credits__: List[str] = ["Hemerson Tacon -- Stack overflow",
                           "Igor Kroitor -- donate 0.5 ETH (~1320$)",
                           "Igor Kroitor -- Helped to solve the problem with exception ConnectionError(10054).",
                           "https://stackoverflow.com/questions/27333671/how-to-solve-the-10054-error"]
-__version__: str = "5.0.0"
+__version__: str = "5.0.1"
 
 SCATTER_SIZE: float = 12.0
 SCATTER_ALPHA: float = 1.0
@@ -54,16 +54,23 @@ WAIT_SUCCESS_SLEEP = 15
 WAIT_SUCCESS_PRINT = True
 USE_WAIT_SUCCESS = True
 
-logger = getLogger()
-logger.setLevel(0)
-basicConfig(level=20, filename='trading.log', format='%(name)s::%(asctime)s::[%(levelname)s] %(message)s')
+logger = getLogger(__name__)
+getLogger('ccxt').setLevel(30)
+getLogger('urllib3').setLevel(30)
+logger.setLevel(10)
+basicConfig(level=0,
+            filename='trading.log',
+            format='%(asctime)s [%(levelname)s] ::: %(message)s ::: '
+                   f'[QUICK_TRADE VERSION: {__version__}] [FUNCTION: %(funcName)s] [FILE "%(module)s", '
+                   'LINE %(lineno)d] %(name)s [%(processName)s: %(process)d] [%(threadName)s: %(thread)d] '
+                   '[FILEPATH: %(pathname)s]')
 
 
 class SuperTrendIndicator(object):
     """
-
     Supertrend (ST)
     """
+
     close: Series
     high: Series
     low: Series
@@ -269,7 +276,7 @@ def wait_success(func):
                 except Exception as e:
                     if not isinstance(e, KeyboardInterrupt):
                         if WAIT_SUCCESS_PRINT:
-                            print(f'An error occurred: {e}')
+                            print(f'An error occurred: {e}, repeat request')
                         logger.error(f'An error occurred: {e}', exc_info=True)
                         sleep(WAIT_SUCCESS_SLEEP)
                         continue
